Retrieve or set the row or column names of a LazyMatrix object.
colnames-LazyMatrix-method.RdRetrieve or set the row or column names of a LazyMatrix object.
Usage
# S4 method for class 'LazyMatrix'
colnames(x)Examples
mat_a <- base::matrix(rep(1, 6), nrow=2, ncol=3)
lazy_a <- LazyMatrix(mat_a, "sd", "mean")
colnames(lazy_a)
#> NULL