Returns the number of columns of the data matrix
ncol-LazyMatrix-method.RdReturns the number of columns of the data matrix
Usage
# S4 method for class 'LazyMatrix'
ncol(x)Examples
mat_a <- base::matrix(rep(1, 6), nrow=2, ncol=3)
lazy_a <- LazyMatrix(mat_a, "sd", "mean")
ncol(lazy_a)
#> [1] 3