Returns the number of rows of the data matrix
nrow-LazyMatrix-method.RdReturns the number of rows of the data matrix
Usage
# S4 method for class 'LazyMatrix'
nrow(x)Examples
mat_a <- base::matrix(rep(1, 6), nrow=2, ncol=3)
lazy_a <- LazyMatrix(mat_a, "sd", "mean")
nrow(lazy_a)
#> [1] 2