Perform the dot product between a LazyColumn and a numeric vector
grapes-times-grapes-LazyColumn-numeric-method.RdComputes the inner product of a LazyColumn object
and a numeric vector.
If y is a scalar, scalar multiplication is performed.
If y is a vector of the same length as the column, the dot product
is performed.
Usage
# S4 method for class 'LazyColumn,numeric'
x %*% y