Perform the dot product between a numeric vectorand a LazyColumn
grapes-times-grapes-numeric-LazyColumn-method.RdComputes the inner product of a numeric vector
and a LazyColumn object.
If x is a scalar, scalar multiplication is performed.
If x is a vector of the same length as the column, the dot product
is performed.
Usage
# S4 method for class 'numeric,LazyColumn'
x %*% y